@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -35,15 +35,19 @@ log = logging.getLogger(__name__)
 # Visuals
 # =============================================================================
 
+
 class ActivityCounter(object):
     """
     Simple class to report progress in a repetitive activity.
     """
-    def __init__(self,
-                 activity: str,
-                 n_total: int = None,
-                 report_every: int = 1000,
-                 loglevel: int = logging.DEBUG) -> None:
+
+    def __init__(
+        self,
+        activity: str,
+        n_total: int = None,
+        report_every: int = 1000,
+        loglevel: int = logging.DEBUG,
+    ) -> None:
         """
         Args:
             activity:
