@@ -45,7 +45,7 @@ def find_nth(s: str, x: str, n: int = 0, overlap: bool = False) -> int:
 
     As per
     https://stackoverflow.com/questions/1883980/find-the-nth-occurrence-of-substring-in-a-string
-    """  # noqa
+    """
     length_of_fragment = 1 if overlap else len(x)
     i = -length_of_fragment
     for _ in range(n + 1):
@@ -64,7 +64,7 @@ def split_string(x: str, n: int) -> List[str]:
     """
     Split string into chunks of length n
     """
-    # https://stackoverflow.com/questions/9475241/split-string-every-nth-character  # noqa
+    # https://stackoverflow.com/questions/9475241/split-string-every-nth-character  # noqa: E501
     return [x[i : i + n] for i in range(0, len(x), n)]
 
 
